function augment_init(augment)
    -- Fetch the owner of the augment.
    local owner = augment:owner();
    local recycle_component = owner:create_component(Lifetime.CardSelectOpen);
    recycle_component.check_component = owner:create_component(Lifetime.CardSelectClose);
    recycle_component.check_component.restore_component = owner:create_component(Lifetime.CardSelectComplete);
    recycle_component.check_component.restore_component.saved_package_id = "";
    recycle_component.check_component.restore_component.saved_code = "";

    recycle_component.check_component.restore_component.damage = 100

    recycle_component.on_update_func = function(self)
        local card = self:owner():field_card(1)
        if card ~= nil then
            self.check_component.restore_component.saved_package_id = card.package_id;
            self.check_component.restore_component.saved_code = card.code;
        end
    end

    recycle_component.check_component.on_update_func = function(self)
        -- Avoid duplicating when no cards are sent
        if #owner:staged_items() == 0 then
            self.restore_component.saved_package_id = "";
            self.restore_component.saved_code = "";
        end
    end

    recycle_component.check_component.restore_component.on_update_func = function(self)
        if self.saved_package_id ~= "" then
            local owner = self:owner()

            local next_cards = owner:field_cards()

            local is_harm = false;
            local i = 0;

            -- Play by regular rules.
            while is_harm == false and i <= #next_cards do
                -- Don't harm if we don't send any further cards in the deck.
                local next_card = owner:field_card(i)
                local card_after = owner:field_card(i + 1)

                if next_card ~= nil then
                    local code = next_card.code
                    local id = next_card.package_id

                    if self.saved_code == "*" then break end;

                    -- Sticky.
                    -- If the next code is * and we have a card after the next card...
                    -- ...then we need to check the saved card against the next-next card.
                    -- This way you can't cheat with sending in Recover 300 in Y code when the next card
                    -- is just Anti-Damage in * code, which would normally let you pass...
                    -- But after that is Colonel Force in Q code. You know what you're doing.
                    -- So do I. Take the damage, dammit.
                    if code == "*" and card_after ~= nil then
                        if card_after.code ~= "*" and card_after.code ~= self.saved_code then
                            is_harm = true;
                        end
                    end

                    -- If the code isn't the same and they're different packages, then you should take damage too.
                    -- It's fine to recycle M-Cannon Q with Colonel Force Q,
                    -- and it's fine to recycle M-Cannon Q with M-Cannon S.
                    -- But you can't recycle M-Cannon Q with Meteors R and expect to get off easy.
                    if self.saved_package_id ~= id then
                        if self .. saved_code ~= code and code ~= "*" then
                            is_harm = true;
                        end
                    end
                end

                i = i + 1;
            end

            if is_harm == true then
                local hp = math.max(1, (owner:health() - self.damage))
                owner:set_health(hp)
                self.damage = math.min(500, self.damage + 100)
            end

            owner:insert_field_card(1, CardProperties.from_package(self.saved_package_id, self.saved_code))

            self.saved_package_id = "";
            self.saved_code = "";
        end
    end
end
